@@ -1,17 +1,18 @@
-/*! Split.js - v1.5.10 */
+/*! Split.js - v1.6.0 */
 
 (function (global, factory) {
     typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
         typeof define === 'function' && define.amd ? define(factory) :
-            (global.Split = factory());
+            (global = global || self, global.Split = factory());
 }(this, (function () { 'use strict';
 
     // The programming goals of Split.js are to deliver readable, understandable and
     // maintainable code, while at the same time manually optimizing for tiny minified file size,
-    // browser compatibility without additional requirements, graceful fallback (IE8 is supported)
+    // browser compatibility without additional requirements
     // and very few assumptions about the user's page layout.
-    var global = window;
-    var document = global.document;
+    var global = typeof window !== 'undefined' ? window : null;
+    var ssr = global === null;
+    var document = !ssr ? global.document : undefined;
 
     // Save a couple long function names that are used frequently.
     // This optimization saves around 400 bytes.
@@ -24,23 +25,21 @@
     var HORIZONTAL = 'horizontal';
     var NOOP = function () { return false; };
 
-    // Figure out if we're in IE8 or not. IE8 will still render correctly,
-    // but will be static instead of draggable.
-    var isIE8 = global.attachEvent && !global[addEventListener];
-
     // Helper function determines which prefixes of CSS calc we need.
     // We only need to do this once on startup, when this anonymous function is called.
     //
     // Tests -webkit, -moz and -o prefixes. Modified from StackOverflow:
     // http://stackoverflow.com/questions/16625140/js-feature-detection-to-detect-the-usage-of-webkit-calc-over-calc/16625167#16625167
-    var calc = (['', '-webkit-', '-moz-', '-o-']
-        .filter(function (prefix) {
-            var el = document.createElement('div');
-            el.style.cssText = "width:" + prefix + "calc(9px)";
+    var calc = ssr
+        ? 'calc'
+        : ((['', '-webkit-', '-moz-', '-o-']
+            .filter(function (prefix) {
+                var el = document.createElement('div');
+                el.style.cssText = "width:" + prefix + "calc(9px)";
 
-            return !!el.style.length
-        })
-        .shift()) + "calc";
+                return !!el.style.length
+            })
+            .shift()) + "calc");
 
     // Helper function checks if its argument is a string-like type
     var isString = function (v) { return typeof v === 'string' || v instanceof String; };
@@ -100,11 +99,7 @@
         var style = {};
 
         if (!isString(size)) {
-            if (!isIE8) {
-                style[dim] = calc + "(" + size + "% - " + gutSize + "px)";
-            } else {
-                style[dim] = size + "%";
-            }
+            style[dim] = calc + "(" + size + "% - " + gutSize + "px)";
         } else {
             style[dim] = size;
         }
@@ -148,6 +143,8 @@
     var Split = function (idsOption, options) {
         if ( options === void 0 ) options = {};
 
+        if (ssr) { return {} }
+
         var ids = idsOption;
         var dimension;
         var clientAxis;
@@ -637,30 +634,27 @@
             // staticly assigning sizes without draggable gutters. Assigns a string
             // to `size`.
             //
-            // IE9 and above
-            if (!isIE8) {
-                // Create gutter elements for each pair.
-                if (i > 0) {
-                    var gutterElement = gutter(i, direction, element.element);
-                    setGutterSize(gutterElement, gutterSize, i);
+            // Create gutter elements for each pair.
+            if (i > 0) {
+                var gutterElement = gutter(i, direction, element.element);
+                setGutterSize(gutterElement, gutterSize, i);
 
-                    // Save bound event listener for removal later
-                    pair[gutterStartDragging] = startDragging.bind(pair);
+                // Save bound event listener for removal later
+                pair[gutterStartDragging] = startDragging.bind(pair);
 
-                    // Attach bound event listener
-                    gutterElement[addEventListener](
-                        'mousedown',
-                        pair[gutterStartDragging]
-                    );
-                    gutterElement[addEventListener](
-                        'touchstart',
-                        pair[gutterStartDragging]
-                    );
+                // Attach bound event listener
+                gutterElement[addEventListener](
+                    'mousedown',
+                    pair[gutterStartDragging]
+                );
+                gutterElement[addEventListener](
+                    'touchstart',
+                    pair[gutterStartDragging]
+                );
 
-                    parent.insertBefore(gutterElement, element.element);
+                parent.insertBefore(gutterElement, element.element);
 
-                    pair.gutter = gutterElement;
-                }
+                pair.gutter = gutterElement;
             }
 
             setElementSize(
@@ -671,7 +665,8 @@
                     i === 0,
                     i === ids.length - 1,
                     gutterAlign
-                )
+                ),
+                i
             );
 
             // After the first iteration, and we have a pair object, append it to the
@@ -721,8 +716,8 @@
                     a.size = trimmed[i - 1];
                     b.size = newSize;
 
-                    setElementSize(a.element, a.size, pair[aGutterSize]);
-                    setElementSize(b.element, b.size, pair[bGutterSize]);
+                    setElementSize(a.element, a.size, pair[aGutterSize], a.i);
+                    setElementSize(b.element, b.size, pair[bGutterSize], b.i);
                 }
             });
         }
@@ -757,13 +752,6 @@
             });
         }
 
-        if (isIE8) {
-            return {
-                setSizes: setSizes,
-                destroy: destroy,
-            }
-        }
-
         return {
             setSizes: setSizes,
             getSizes: getSizes,
